@@ -35,7 +35,7 @@
 #include <fnmatch.h>
 #include <libgen.h>
 #include <ctype.h>
-//
+#include <sys/file.h>
 #include <sys/utsname.h>
 
 #include <dirent.h>
@@ -66,6 +66,8 @@
 #include "../common/prototypes.h"
 #include "prototypes.h"
 
+#include "config.h"
+
 #include <metalink/metalink_parser.h>
 
 // Enum in order of preference
