@@ -29,6 +29,7 @@ TDNFGetErrorString(
     uint32_t dwError = 0;
     char* pszError = NULL;
     char* pszSystemError = NULL;
+    const char* pszCurlError = NULL;
     int i = 0;
     int nCount = 0;
     uint32_t dwActualError = 0;
@@ -60,6 +61,18 @@ TDNFGetErrorString(
         }
     }
 
+    //Get curl error
+    if(!pszError && TDNFIsCurlError(dwErrorCode))
+    {
+        dwActualError = TDNFGetCurlError(dwErrorCode);
+        pszCurlError = curl_easy_strerror(dwActualError);
+        if(pszCurlError)
+        {
+            dwError = TDNFAllocateString(pszCurlError, &pszError);
+            BAIL_ON_TDNF_ERROR(dwError);
+        }
+    }
+
     //If the above attempts did not yield an error string,
     //do default unknown error.
     if(!pszError)
@@ -110,6 +123,19 @@ TDNFGetSystemError(
     return dwSystemError;
 }
 
+uint32_t
+TDNFGetCurlError(
+    uint32_t dwError
+    )
+{
+    uint32_t dwCurlError = 0;
+    if(TDNFIsCurlError(dwError))
+    {
+        dwCurlError = dwError - ERROR_TDNF_CURL_BASE;
+    }
+    return dwCurlError;
+}
+
 int
 TDNFIsGlob(
     const char* pszString
@@ -219,6 +245,89 @@ error:
     goto cleanup;
 }
 
+uint32_t
+TDNFIsFileOrSymlink(
+    const char* pszPath,
+    int* pnPathIsFile
+    )
+{
+    uint32_t dwError = 0;
+    int nPathIsFile = 0;
+    struct stat stStat = {0};
+
+    if(!pnPathIsFile || IsNullOrEmptyString(pszPath))
+    {
+        dwError = ERROR_TDNF_INVALID_PARAMETER;
+        BAIL_ON_TDNF_ERROR(dwError);
+    }
+
+    if(stat(pszPath, &stStat))
+    {
+        if (errno == ENOENT)
+	{
+            nPathIsFile = 0;
+        }
+        else
+        {
+            dwError = errno;
+            BAIL_ON_TDNF_SYSTEM_ERROR(dwError);
+        }
+    }
+    else
+    {
+        nPathIsFile = S_ISREG(stStat.st_mode) | S_ISLNK(stStat.st_mode);
+    }
+
+    *pnPathIsFile = nPathIsFile;
+cleanup:
+    return dwError;
+
+error:
+    if(pnPathIsFile)
+    {
+        *pnPathIsFile = 0;
+    }
+    goto cleanup;
+}
+
+uint32_t
+TDNFGetFileSize(
+    const char* pszPath,
+    int *pnSize
+    )
+{
+    uint32_t dwError = 0;
+    struct stat stStat = {0};
+
+    if(!pnSize || IsNullOrEmptyString(pszPath))
+    {
+        dwError = ERROR_TDNF_INVALID_PARAMETER;
+        BAIL_ON_TDNF_ERROR(dwError);
+    }
+
+    if(stat(pszPath, &stStat))
+    {
+        dwError = errno;
+        BAIL_ON_TDNF_SYSTEM_ERROR(dwError);
+    }
+    else
+    {
+        if (S_ISREG(stStat.st_mode))
+        {
+            *pnSize = stStat.st_size;
+        }
+    }
+cleanup:
+    return dwError;
+
+error:
+    if(pnSize)
+    {
+        *pnSize = 0;
+    }
+    goto cleanup;
+}
+
 uint32_t
 TDNFIsDir(
     const char* pszPath,
